@@ -303,12 +303,6 @@ canonicalize_filename (const char *filename)
   return canon;
 }
 
-/**
- * _g_local_file_new:
- * @filename: filename of the file to create.
- * 
- * Returns: new local #GFile.
- **/
 GFile *
 _g_local_file_new (const char *filename)
 {
@@ -955,7 +949,8 @@ g_local_file_query_filesystem_info (GFile         *file,
      free == 0 case as "both of these are invalid".
    */
 #ifndef G_OS_WIN32
-  if (statfs_buffer.f_bavail == 0 && statfs_buffer.f_bfree == 0)
+  if (statfs_result == 0 &&
+      statfs_buffer.f_bavail == 0 && statfs_buffer.f_bfree == 0)
     no_size = TRUE;
 #endif
   
@@ -1720,12 +1715,11 @@ _g_local_file_has_trash_dir (const char *dirname, dev_t dir_dev)
   char uid_str[32];
   struct stat global_stat, trash_stat;
   gboolean res;
-  int statres;
-      
+
   if (g_once_init_enter (&home_dev_set))
     {
       struct stat home_stat;
-      
+
       g_stat (g_get_home_dir (), &home_stat);
       home_dev = home_stat.st_dev;
       g_once_init_leave (&home_dev_set, 1);
@@ -1739,9 +1733,8 @@ _g_local_file_has_trash_dir (const char *dirname, dev_t dir_dev)
   if (topdir == NULL)
     return FALSE;
 
-  globaldir = g_build_filename (topdir, ".Trash", NULL); 
-  statres = g_lstat (globaldir, &global_stat);
- if (g_lstat (globaldir, &global_stat) == 0 &&
+  globaldir = g_build_filename (topdir, ".Trash", NULL);
+  if (g_lstat (globaldir, &global_stat) == 0 &&
       S_ISDIR (global_stat.st_mode) &&
       (global_stat.st_mode & S_ISVTX) != 0)
     {
@@ -1759,7 +1752,7 @@ _g_local_file_has_trash_dir (const char *dirname, dev_t dir_dev)
   /* No global trash dir, or it failed the tests, fall back to $topdir/.Trash-$uid */
   uid = geteuid ();
   g_snprintf (uid_str, sizeof (uid_str), "%lu", (unsigned long) uid);
-  
+
   tmpname = g_strdup_printf (".Trash-%s", uid_str);
   trashdir = g_build_filename (topdir, tmpname, NULL);
   g_free (tmpname);
@@ -1768,17 +1761,15 @@ _g_local_file_has_trash_dir (const char *dirname, dev_t dir_dev)
     {
       g_free (topdir);
       g_free (trashdir);
-      return
-	S_ISDIR (trash_stat.st_mode) &&
-	trash_stat.st_uid == uid;
+      return S_ISDIR (trash_stat.st_mode) &&
+	     trash_stat.st_uid == uid;
     }
   g_free (trashdir);
 
   /* User specific trash didn't exist, can we create it? */
   res = g_access (topdir, W_OK) == 0;
-  
   g_free (topdir);
-  
+
   return res;
 }
 
@@ -2154,6 +2145,10 @@ g_local_file_make_symbolic_link (GFile         *file,
 	g_set_error_literal (error, G_IO_ERROR,
                              G_IO_ERROR_INVALID_FILENAME,
                              _("Invalid filename"));
+      else if (errsv == EPERM)
+	g_set_error (error, G_IO_ERROR,
+		     G_IO_ERROR_NOT_SUPPORTED,
+		     _("Filesystem does not support symbolic links"));
       else
 	g_set_error (error, G_IO_ERROR,
 		     g_io_error_from_errno (errsv),
