@@ -20,10 +20,11 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 
 #include "glocalfilemonitor.h"
 #include "giomodule-priv.h"
+#include "gioerror.h"
 #include "glibintl.h"
 
 #include <string.h>
@@ -106,8 +107,7 @@ g_local_file_monitor_finalize (GObject *object)
       local_monitor->filename = NULL;
     }
 
-  if (G_OBJECT_CLASS (g_local_file_monitor_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_local_file_monitor_parent_class)->finalize) (object);
+  G_OBJECT_CLASS (g_local_file_monitor_parent_class)->finalize (object);
 }
 
 static void g_local_file_monitor_class_init (GLocalFileMonitorClass *klass)
@@ -169,13 +169,6 @@ get_default_local_file_monitor (gpointer data)
     return (gpointer)G_TYPE_INVALID;
 }
 
-/**
- * g_local_file_monitor_new:
- * @pathname: path name to monitor.
- * @flags: #GFileMonitorFlags.
- * 
- * Returns: a new #GFileMonitor for the given @pathname. 
- **/
 GFileMonitor*
 _g_local_file_monitor_new (const char         *pathname,
 			   GFileMonitorFlags   flags,
@@ -194,7 +187,8 @@ _g_local_file_monitor_new (const char         *pathname,
   if (type != G_TYPE_INVALID)
     monitor = G_FILE_MONITOR (g_object_new (type, "filename", pathname, NULL));
   else
-    g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED, _("Unable to find default local file monitor type"));
+    g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_FAILED,
+                         _("Unable to find default local file monitor type"));
 
   /* This is non-null on first pass here. Unref the class now.
    * This is to avoid unloading the module and then loading it
